@@ -118,7 +118,7 @@ private:
 	int		len, pint;
 	bool	empty;
 public:
-	Cmovavg(int filtlen);
+	Cmovavg(int filtlen = 64);
 	~Cmovavg();
 	double run(double a);
 	void setLength(int filtlen);
@@ -167,7 +167,6 @@ private:
 	double k1;
 	double k2;
 	double k3;
-	bool isvalid;
 public:
 	goertzel(int n, double freq, double sr);
 	~goertzel();
