@@ -54,6 +54,26 @@ enum {
 	MODE_CW,
 
 	MODE_CONTESTIA,
+	MODE_CONTESTIA_4_125,
+	MODE_CONTESTIA_4_250,
+	MODE_CONTESTIA_4_500,
+	MODE_CONTESTIA_4_1000,
+	MODE_CONTESTIA_4_2000,
+	MODE_CONTESTIA_8_125,
+	MODE_CONTESTIA_8_250,
+	MODE_CONTESTIA_8_500,
+	MODE_CONTESTIA_8_1000,
+	MODE_CONTESTIA_8_2000,
+	MODE_CONTESTIA_16_500,
+	MODE_CONTESTIA_16_1000,
+	MODE_CONTESTIA_16_2000,
+	MODE_CONTESTIA_32_1000,
+	MODE_CONTESTIA_32_2000,
+	MODE_CONTESTIA_64_500,
+	MODE_CONTESTIA_64_1000,
+	MODE_CONTESTIA_64_2000,
+	MODE_CONTESTIA_FIRST = MODE_CONTESTIA_4_125,
+	MODE_CONTESTIA_LAST = MODE_CONTESTIA_64_2000,
 
 	MODE_DOMINOEXMICRO,
 	MODE_DOMINOEX4,
@@ -152,14 +172,23 @@ enum {
 	MODE_8PSK_LAST = MODE_8PSK1200F,
 
 	MODE_OLIVIA,
+	MODE_OLIVIA_4_125,
 	MODE_OLIVIA_4_250,
-	MODE_OLIVIA_8_250,
 	MODE_OLIVIA_4_500,
+	MODE_OLIVIA_4_1000,
+	MODE_OLIVIA_4_2000,
+	MODE_OLIVIA_8_125,
+	MODE_OLIVIA_8_250,
 	MODE_OLIVIA_8_500,
-	MODE_OLIVIA_16_500,
 	MODE_OLIVIA_8_1000,
+	MODE_OLIVIA_8_2000,
+	MODE_OLIVIA_16_500,
 	MODE_OLIVIA_16_1000,
+	MODE_OLIVIA_16_2000,
 	MODE_OLIVIA_32_1000,
+	MODE_OLIVIA_32_2000,
+	MODE_OLIVIA_64_500,
+	MODE_OLIVIA_64_1000,
 	MODE_OLIVIA_64_2000,
 	MODE_OLIVIA_FIRST = MODE_OLIVIA,
 	MODE_OLIVIA_LAST = MODE_OLIVIA_64_2000,
