@@ -1,16 +1,7 @@
 /*
  *    morse.h  --  morse code tables
  *
- *    Copyright (C) 2004
- *      Lawrence Glaister (ve7it@shaw.ca)
- *      Tomi Manninen (oh2bns@sral.fi)
- *
- *    This modem borrowed heavily from other gmfsk modems and
- *    also from the unix-cw project. I would like to thank those
- *    authors for enriching my coding experience by providing
- *    and supporting open source.
- *
- *    This file is part of fldigi.
+ *    Copyright (C) 2017
  *
  *    Fldigi is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -30,28 +21,25 @@
 #ifndef _MORSE_H
 #define _MORSE_H
 
+#include <string>
+
 #define	MorseTableSize	256
  
 #define	CW_DOT_REPRESENTATION	'.'
 #define	CW_DASH_REPRESENTATION	'-'
 
-
-struct CW_TABLE {
-	char chr;	/* The character(s) represented */
-	const char *prt;	/* The printable representation of the character */
-	const char *rpr;	/* Dot-dash shape of the character */
-};
-
-struct CW_XMT_TABLE {
-	unsigned long code;
-	const    char *prt;
+struct CWstruct {
+	bool			enabled;	// true if character is active
+	std::string		chr;		// utf-8 string representation of character
+	std::string		prt;		// utf-8 printable representation
+	std::string		rpr;		// Dot-dash code representation
 };
 
 class cMorse {
 private:
-	CW_TABLE 		*cw_rx_lookup[256];
-	CW_XMT_TABLE 	cw_tx_lookup[256];
-	unsigned int 	tokenize_representation(const char *representation);
+	static CWstruct	cw_table[];
+	std::string utf8;
+	std::string toprint;
 public:
 	cMorse() { 
 		init(); 
@@ -59,9 +47,11 @@ public:
 	~cMorse() {
 	}
 	void init();
-	const char	*rx_lookup(char *r);
-	unsigned long	tx_lookup(int c);
-	const char *tx_print(int c);
+	void enable(std::string, bool);
+	std::string		rx_lookup(std::string);
+	std::string		tx_lookup(int);
+	std::string		tx_print() { return toprint; }
+	int  tx_length(int);
 };
 
 #endif
