@@ -71,7 +71,7 @@ public:
 	void RestoreTIO(bool b) { restore_tio = b; }
 	bool RestoreTIO() { return restore_tio; }
 
-	void Stopbits(int n) {stopbits = (n == 1 ? 1 : 2);}
+	void Stopbits(int n) { stopbits = n; }
 	int  Stopbits() { return stopbits;}
 
 	int  ReadBuffer (unsigned char *b, int nbr);
@@ -180,7 +180,7 @@ public:
 	void RestoreTIO(bool b) { restore_tio = b; }
 	bool RestoreTIO() { return restore_tio; }
 
-	void Stopbits(int n) {stopbits = (n == 1 ? 1 : 2);}
+	void Stopbits(int n) { stopbits = n; }
 	int  Stopbits() { return stopbits;}
 
 //Members
