@@ -120,6 +120,9 @@ bool Cserial::OpenPort()  {
 	newtio.c_iflag &= ~ICRNL;
 
  	switch(baud) {
+		case 50:
+			speed = B50;
+			break;
  		case 300:
 			speed = B300;
 			break;
@@ -295,6 +298,10 @@ void Cserial::FlushBuffer()
 
 #else // __MINGW32__
 
+//======================================================================
+// Win32 support code
+//======================================================================
+
 #include "estrings.h"
 
 using namespace std;
@@ -585,19 +592,58 @@ BOOL Cserial::ConfigurePort(DWORD	BaudRate,
 		return FALSE;
 	}
 
+	LOG_INFO("\n\
+Get Comm State:\n\
+DCB.DCBlength       %d\n\
+DCB.Baudrate        %d\n\
+DCB.ByteSize        %d\n\
+DCB.Parity          %d\n\
+DCB.StopBits        %d\n\
+DCB.Binary          %d\n\
+DCB.fDtrControl     %d\n\
+DCB.fRtsControl     %d\n\
+DCB.fDsrSensitivity %d\n\
+DCB.fParity         %d\n\
+DCB.fOutX           %d\n\
+DCB.fInX            %d\n\
+DCB.fNull           %d\n\
+DCB.XonChar         %d\n\
+DCB.XoffChar        %d\n\
+DCB.fAbortOnError   %d\n\
+DCB.fOutxCtsFlow    %d\n\
+DCB.fOutxDsrFlow    %d\n",
+	(int)dcb.DCBlength,
+	(int)dcb.BaudRate,
+	(int)dcb.ByteSize,
+	(int)dcb.Parity,
+	(int)dcb.StopBits,
+	(int)dcb.fBinary,
+	(int)dcb.fDtrControl,
+	(int)dcb.fRtsControl,
+	(int)dcb.fDsrSensitivity,
+	(int)dcb.fParity,
+	(int)dcb.fOutX,
+	(int)dcb.fInX,
+	(int)dcb.fNull,
+	(int)dcb.XonChar,
+	(int)dcb.XoffChar,
+	(int)dcb.fAbortOnError,
+	(int)dcb.fOutxCtsFlow,
+	(int)dcb.fOutxDsrFlow);
+
 	dcb.BaudRate			= BaudRate;
 	dcb.ByteSize			= ByteSize;
-	dcb.Parity				= Parity ;
-	dcb.StopBits			= (StopBits == 1 ? ONESTOPBIT : TWOSTOPBITS);
-	dcb.fBinary				= TRUE;
-	dcb.fDsrSensitivity		= FALSE;
-	dcb.fParity				= dwParity;
-	dcb.fOutX				= FALSE;
-	dcb.fInX				= FALSE;
-	dcb.fNull				= FALSE;
-	dcb.fAbortOnError		= TRUE;
-	dcb.fOutxCtsFlow		= FALSE;
-	dcb.fOutxDsrFlow		= FALSE;
+	dcb.Parity				= Parity;
+	dcb.StopBits			= (StopBits == 1) ? 0 : 2;
+//	dcb.fBinary				= TRUE;
+//	dcb.fDsrSensitivity		= FALSE;
+//	dcb.fParity				= dwParity;
+//	dcb.fOutX				= FALSE;
+//	dcb.fInX				= FALSE;
+//	dcb.fNull				= FALSE;
+//	dcb.fAbortOnError		= TRUE;
+//	dcb.fOutxCtsFlow		= FALSE;
+//	dcb.fOutxDsrFlow		= FALSE;
 
 	if (dtr)
 		dcb.fDtrControl = DTR_CONTROL_ENABLE;
@@ -615,11 +661,52 @@ BOOL Cserial::ConfigurePort(DWORD	BaudRate,
 			dcb.fRtsControl = RTS_CONTROL_DISABLE;
 	}
 
+	LOG_INFO("\n\
+Set Comm State:\n\
+DCB.DCBlength       %d\n\
+DCB.Baudrate        %d\n\
+DCB.ByteSize        %d\n\
+DCB.Parity          %d\n\
+DCB.StopBits        %d\n\
+DCB.Binary          %d\n\
+DCB.fDtrControl     %d\n\
+DCB.fRtsControl     %d\n\
+DCB.fDsrSensitivity %d\n\
+DCB.fParity         %d\n\
+DCB.fOutX           %d\n\
+DCB.fInX            %d\n\
+DCB.fNull           %d\n\
+DCB.XonChar         %d\n\
+DCB.XoffChar        %d\n\
+DCB.fAbortOnError   %d\n\
+DCB.fOutxCtsFlow    %d\n\
+DCB.fOutxDsrFlow    %d\n",
+	(int)dcb.DCBlength,
+	(int)dcb.BaudRate,
+	(int)dcb.ByteSize,
+	(int)dcb.Parity,
+	(int)dcb.StopBits,
+	(int)dcb.fBinary,
+	(int)dcb.fDtrControl,
+	(int)dcb.fRtsControl,
+	(int)dcb.fDsrSensitivity,
+	(int)dcb.fParity,
+	(int)dcb.fOutX,
+	(int)dcb.fInX,
+	(int)dcb.fNull,
+	(int)dcb.XonChar,
+	(int)dcb.XoffChar,
+	(int)dcb.fAbortOnError,
+	(int)dcb.fOutxCtsFlow,
+	(int)dcb.fOutxDsrFlow);
+
 	bPortReady = SetCommState(hComm, &dcb);
+
 	if(bPortReady == 0) {
+		errno = GetLastError();
+		LOG_PERROR(win_error_string(errno).c_str());
 		CloseHandle(hComm);
 		hComm = INVALID_HANDLE_VALUE;
-		LOG_PERROR("Port not available");
 		return FALSE;
 	}
 
@@ -670,9 +757,11 @@ void Cserial::SetPTT(bool b)
 	SetCommState(hComm, &dcb);
 }
 
+//======================================================================
+// end Win32 code
+//======================================================================
 #endif //__MINGW32__
 
-
 #ifdef __WOE32__
 #include <sstream>
 #include "re.h"
@@ -710,4 +799,5 @@ void tty_to_com(string& port)
 	ss.seekp(0);
 	port = ss.str();
 }
+
 #endif
