@@ -529,7 +529,8 @@ void WFdisp::processFFT() {
 		static const int log2disp100 = log2disp(-100);
 		double vscale = 2.0 / FFT_LEN;
 
-		memset(wfbuf, 0, FFT_LEN * sizeof(*wfbuf));
+		for (int i = 0; i < FFT_LEN; i++) wfbuf[i] = 0;
+
 		void *pv = static_cast<void*>(wfbuf);
 		wf_fft_type *pbuf = static_cast<wf_fft_type*>(pv);
 
@@ -1864,7 +1865,9 @@ waterfall::waterfall(int x0, int y0, int w0, int h0, char *lbl) :
 void waterfall::UI_select(bool on) {
 	if (on) {
 		if (!progdefaults.WF_UIrev)
-			btnRev->hide(); else btnRev->show();
+			btnRev->hide();
+		else 
+			btnRev->show();
 		if (!progdefaults.WF_UIwfcarrier)
 			wfcarrier->hide(); else wfcarrier->show();
 		if (!progdefaults.WF_UIwfreflevel)
@@ -1899,7 +1902,10 @@ void waterfall::UI_select(bool on) {
 		}
 //if (noUI) xmtrcv->hide();
 	} else {
-		btnRev->show();
+//		btnRev->show();
+		if (!progdefaults.WF_UIrev)
+			btnRev->hide();
+		else btnRev->show();
 		wfcarrier->show();
 		wfRefLevel->show();
 		wfAmpSpan->show();
