@@ -797,7 +797,7 @@ int FTextRX::handle_qso_data(int start, int end)
 		}
 	}
 
-	char *sz = get_word(start, end, "", num_words);
+	char *sz = get_word(start, end, progdefaults.nonwordchars.c_str(), num_words);
 
 	if (!sz)
 		return 0;
@@ -1667,7 +1667,7 @@ void FTextRX::menu_cb(size_t item)
 				inp_JOTA_spc->value(s.c_str());
 			else
 				cboCountry->value(s.c_str());
-				return;
+			return;
 		case RX_MENU_PROVINCE:
 			if (progdefaults.logging == LOG_NAS)
 				inpXchgIn->value(s.c_str());
