@@ -12,7 +12,7 @@
 //
 // fldigi is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 4 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // Fldigi is distributed in the hope that it will be useful,
@@ -551,8 +551,10 @@ static FILE* open_file(const char* name, const char* suffix)
 				newfn.seekp(p);
 				oldfn << i;
 				newfn << i + 1;
+				remove(newfn.str().c_str());
 				rename(oldfn.str().c_str(), newfn.str().c_str());
 			}
+			remove(oldfn.str().c_str());
 			rename(name, oldfn.str().c_str());
 		}
 		fp = fl_fopen(name, "wb");
